<?php
//
// Nagios XI API Documentation
// Copyright (c) 2008-2018 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/../includes/common.inc.php');

// Initialization stuff
pre_init();
init_session();

// Grab GET or POST variables and check pre-reqs
grab_request_vars();
check_prereqs();
check_authentication(false);

if (!is_admin()) {
    die(_('Not authorized to view this page.'));
}

route_request();

function route_request()
{
    $page = grab_request_var("page", "");

    switch ($page) {
        default:
            show_main_api_page();
            break;
    }
}

function show_main_api_page()
{
    $apikey = get_apikey();

    do_page_start(array("page_title" => _('REST API - Config Reference')), true);
?>

    <!-- Keep the help section part of the page -->
    <script src="../includes/js/clipboard.min.js"></script>
    <script>
    $(document).ready(function() {
        resize_nav();
        new Clipboard('.copy');
        $(window).resize(function() {
            resize_nav();
        });
    });

    function resize_nav() {
        var width = $('.nav-box').width();
        $('.help-right-nav').css('width', width);
    }
    </script>

    <div class="container-fluid help">
        <div class="row">
            <div class="col-sm-8 col-md-9 col-lg-9">

                <h1><?php echo _('REST API - Config Reference'); ?></h1>
                <p style="padding: 0;"><?php echo _('With the new API in Nagios XI 5 we linked it up directly with the Core Config Manager. This allows creation and deletion of items directly from the API.'); ?> <em><?php echo _('This API section is'); ?> <b><?php echo _('admin only'); ?></b>.</em></p>

                <div class="message">
                    <ul class="actionMessage" style="margin-top: 2em;">
                        <li><i class="fa fa-exclamation l"></i> <b><?php echo _('Note'); ?>:</b> <?php echo _('By default the Nagios Core service <em><b>is not restarted</b></em> when an object is created or deleted via the API.'); ?> <?php echo _('To apply the configuration, use the'); ?> <a href="api-system-reference.php#system-applyconfig">GET system/applyconfig</a> <?php echo _('request after making the changes you want to apply'); ?>. <?php echo _('You may change the default behavior by passing the argument <code>applyconfig=1</code> in your API request which will import the data into your configuration and <em><b>will restart</b></em> the Nagios Core service.'); ?></li>
                    </ul>
                </div>

                <div class="message">
                    <ul class="actionMessage" style="margin-top: 0;">
                        <li>
                            <i class="fa fa-exclamation l"></i> <b><?php echo _('Note'); ?>:</b> <?php echo _('If you need to skip the per-item config verification add <code>force=1</code> to the config API request. This is especially helpful when applying an object that uses a template and may be inheriting one of the required parameters such as <code>check_command</code> which the CCM verification will not know about.'); ?> <em><?php echo _('Warning: This can cause the apply config to fail if not used properly.'); ?></em>
                        </li>
                    </ul>
                </div>

                <h3 class="help-section-head"><?php echo _('Hosts'); ?></h3>

                <div class="help-section obj-reference">
                    <a name="add-host"></a>
                    <h4><span class="label label-info">POST</span> config/host</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command creates a new host object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>host_name</td>
                                            <td>host name</td>
                                        </tr>
                                        <tr>
                                            <td>address</td>
                                            <td>ip address</td>
                                        </tr>
                                        <tr>
                                            <td>max_check_attempts</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>check_period</td>
                                            <td>timeperiod_name</td>
                                        </tr>
                                        <tr>
                                            <td>contacts<br><em>or</em><br>contact_groups</td>
                                            <td>contacts<br><em>or</em><br>contact_groups</td>
                                        </tr>
                                        <tr>
                                            <td>notification_interval</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>notification_period</td>
                                            <td>timeperiod_name</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal host directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-add-host"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-add-host">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/host?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d "host_name=testapihost&amp;address=127.0.0.1&amp;check_command=check_ping\!3000,80%\!5000,100%&amp;max_check_attempts=2&amp;check_period=24x7&amp;contacts=nagiosadmin&amp;notification_interval=5&amp;notification_period=24x7&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added testapihost to the system. Config applied, Nagios Core was restarted."
}
</pre>
                                <h6><?php echo _('Response (Failure)'); ?>:</h6>
                                <pre>{
    "error": "Missing required variables",
    "missing": [
        "host_name",
        "address",
        "max_check_attempts",
        "check_period",
        "notification_interval",
        "notification_period",
        "contacts OR contact_groups"
    ]
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="help-section obj-reference">
                    <a name="delete-host"></a>
                    <h4><span class="label label-danger">DELETE</span> config/host</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command removes a host object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>host_name</td>
                                            <td>host name</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-delete-host"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-delete-host">curl -XDELETE "<?php echo get_base_url(); ?>api/v1/config/host?apikey=<?php echo $apikey; ?>&amp;pretty=1&amp;host_name=testapihost&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Removed testapihost from the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <h3 class="help-section-head"><?php echo _('Services'); ?></h3>

                <div class="help-section obj-reference">
                    <a name="add-service"></a>
                    <h4><span class="label label-info">POST</span> config/service</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command creates a new service object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>host_name</td>
                                            <td>host name</td>
                                        </tr>
                                        <tr>
                                            <td>service_description</td>
                                            <td>service name</td>
                                        </tr>
                                        <tr>
                                            <td>check_command</td>
                                            <td>command_name</td>
                                        </tr>
                                        <tr>
                                            <td>max_check_attempts</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>check_interval</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>retry_interval</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>check_period</td>
                                            <td>timeperiod_name</td>
                                        </tr>
                                        <tr>
                                            <td>notification_interval</td>
                                            <td>#</td>
                                        </tr>
                                        <tr>
                                            <td>notification_period</td>
                                            <td>timeperiod_name</td>
                                        </tr>
                                        <tr>
                                            <td>contacts<br><em>or</em><br>contact_groups</td>
                                            <td>contacts<br><em>or</em><br>contact_groups</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal service directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-add-service"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-add-service">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/service?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d "host_name=testapihost&amp;service_description=PING&amp;check_command=check_ping\!3000,80%\!5000,100%&amp;check_interval=5&amp;retry_interval=5&amp;max_check_attempts=2&amp;check_period=24x7&amp;contacts=nagiosadmin&amp;notification_interval=5&amp;notification_period=24x7&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added testapihost :: PING to the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="help-section obj-reference">
                    <a name="delete-service"></a>
                    <h4><span class="label label-danger">DELETE</span> config/service</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command removes a service object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>host_name</td>
                                            <td>host name</td>
                                        </tr>
                                        <tr>
                                            <td>service_description</td>
                                            <td>service name</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-delete-service"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-delete-service">curl -XDELETE "<?php echo get_base_url(); ?>api/v1/config/service?apikey=<?php echo $apikey; ?>&amp;pretty=1&amp;host_name=testapihost&amp;service_description=PING&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Removed testapihost :: PING from the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <h3 class="help-section-head"><?php echo _('Groups'); ?></h3>

                <div class="help-section obj-reference">
                    <a name="add-hostgroup"></a>
                    <h4><span class="label label-info">POST</span> config/hostgroup</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command creates a new hostgroup object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>hostgroup_name</td>
                                            <td>hostgroup name</td>
                                        </tr>
                                        <tr>
                                            <td>alias</td>
                                            <td>alias</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal hostgroup directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-add-hg"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-add-hg">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/hostgroup?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d "hostgroup_name=testapihostgroup&amp;alias=HostGroup&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added testapihostgroup to the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="help-section obj-reference">
                    <a name="add-servicegroup"></a>
                    <h4><span class="label label-info">POST</span> config/servicegroup</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This command creates a new servicegroup object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>servicegroup_name</td>
                                            <td>servicegroup name</td>
                                        </tr>
                                        <tr>
                                            <td>alias</td>
                                            <td>alias</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal servicegroup directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-add-sg"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-add-sg">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/servicegroup?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d "servicegroup_name=testapiservicegroup&amp;alias=ServiceGroup&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added testapiservicegroup to the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <h3 class="help-section-head"><?php echo _('Commands'); ?></h3>

                <div class="help-section obj-reference">
                    <a name="add-command"></a>
                    <h4><span class="label label-info">POST</span> config/command</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This endpoint creates a new command object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>command_name</td>
                                            <td>command name</td>
                                        </tr>
                                        <tr>
                                            <td>command_line</td>
                                            <td>command line</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal command directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-add-command"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-add-command">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/command?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d "command_name=check_touch_tmp&amp;command_line=touch /tmp/testing&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added check_touch_tmp to the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="help-section obj-reference">
                    <a name="delete-command"></a>
                    <h4><span class="label label-danger">DELETE</span> config/command</h4>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('This endpoint deletes a command object.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Required Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>command_name</td>
                                            <td>command name</td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-delete-command"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-delete-command">curl -XDELETE "<?php echo get_base_url(); ?>api/v1/config/command?apikey=<?php echo $apikey; ?>&amp;pretty=1&amp;command_name=check_touch_tmp&amp;applyconfig=1"</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Successfully added check_touch_tmp to the system. Config applied, Nagios Core was restarted."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

                <h3 class="help-section-head"><?php echo _('Raw Import'); ?></h3>

                <div class="help-section obj-reference">
                    <a name="import"></a>
                    <h4><span class="label label-info">POST</span> config/import</h4>
                    <div class="alert alert-warning" style="margin-top: 20px;">
                        <i class="fa fa-14 fa-exclamation-triangle"></i> <?php echo _('<b>Warning!</b> These configurations are not checked for validity. You should be sure your configuration will apply before sending your raw config data to this endpoint.'); ?>
                    </div>
                    <div class="container-fluid" style="padding: 0 5px;">
                        <div class="row">
                            <div class="col-md-5 col-lg-4 col-xl-3">
                                <p><?php echo _('Import raw configurations into the CCM. You can see a full list of configuratin objects that you can use in the') . ' <a href="https://assets.nagios.com/downloads/nagioscore/docs/nagioscore/4/en/objectdefinitions.html" target="_new">'. _('Object Definitions') . '</a> ' . _('section of the Core docs.'); ?></p>
                                <table class="table table-condensed table-bordered table-hover" style="margin-bottom: 10px;">
                                    <thead>
                                        <tr>
                                            <th><?php echo _('Optional Parameters'); ?></th>
                                            <th><?php echo _('Value Type'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td>overwrite</td>
                                            <td><b>0</b> (default) or 1</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><em>** <?php echo _('All normal config directives are able to be used like normal core config definition files.'); ?></em></p>
                            </div>
                            <div class="col-md-7 col-lg-8 col-xl-9">
                                <h6><?php echo _('Example cURL Request'); ?>: <a class="copy fr" data-clipboard-target="#cmd-import"><?php echo _('Copy'); ?></a></h6>
                                <pre><code id="cmd-import">curl -XPOST "<?php echo get_base_url(); ?>api/v1/config/import?apikey=<?php echo $apikey; ?>&amp;pretty=1" -d '
define host {
    host_name           newhost.example
    address             127.0.0.1
    use                 xiwizard_generic_host
    max_check_attempts  5
    check_interval      5
    check_period        xi_timeperiod_24x7
    notification_period xi_timeperiod_24x7
    register            1
}'</code></pre>
                                <h6><?php echo _('Response (Success)'); ?>:</h6>
                                <pre>{
    "success": "Imported configuration data."
}
</pre>
                                <h6><?php echo _('Response (Failure)'); ?>:</h6>
                                <pre>{
    "error": "Import failed. Configuration passed may not be formatted properly."
}
</pre>
                            </div>
                        </div>
                    </div>
                </div>

             </div>
             <div class="col-sm-4 col-md-3 col-lg-3 nav-box">
                <div class="well help-right-nav">
                    <h5><?php echo _('REST API - Config Reference'); ?></h5>
                    <p style="margin: 10px 0; padding: 0;"><?php echo _('Hosts'); ?></p>
                    <ul>
                        <li><span class="label label-info">POST</span> <a href="#add-host">config/host</a></li>
                        <li><span class="label label-danger">DELETE</span> <a href="#delete-host">config/host</a></li>
                    </ul>
                    <p style="margin: 10px 0; padding: 0;"><?php echo _('Services'); ?></p>
                    <ul>
                        <li><span class="label label-info">POST</span> <a href="#add-service">config/service</a></li>
                        <li><span class="label label-danger">DELETE</span> <a href="#delete-service">config/service</a></li>
                    </ul>
                    <p style="margin: 10px 0; padding: 0;"><?php echo _('Groups'); ?></p>
                    <ul>
                        <li><span class="label label-info">POST</span> <a href="#add-hostgroup">config/hostgroup</a></li>
                        <li><span class="label label-info">POST</span> <a href="#add-servicegroup">config/servicegroup</a></li>
                    </ul>
                    <p style="margin: 10px 0; padding: 0;"><?php echo _('Commands'); ?></p>
                    <ul>
                        <li><span class="label label-info">POST</span> <a href="#add-command">config/command</a></li>
                        <li><span class="label label-danger">DELETE</span> <a href="#delete-command">config/command</a></li>
                    </ul>
                    <p style="margin: 10px 0; padding: 0;"><?php echo _('Raw Import'); ?></p>
                    <ul>
                        <li><span class="label label-info">POST</span> <a href="#import">config/import</a></li>
                    </ul>
                </div>
            </div>
        </div>
    </div>

<?php
    do_page_end(true);
}
?>